package cn.com.infosec.asn1.ess;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERUTF8String;

public class ContentHints extends ASN1Encodable {
   private DERUTF8String contentDescription;
   private DERObjectIdentifier contentType;

   public static ContentHints getInstance(Object o) {
      if (o != null && !(o instanceof ContentHints)) {
         if (o instanceof ASN1Sequence) {
            return new ContentHints((ASN1Sequence)o);
         } else {
            throw new IllegalArgumentException("unknown object in 'ContentHints' factory : " + o.getClass().getName() + ".");
         }
      } else {
         return (ContentHints)o;
      }
   }

   private ContentHints(ASN1Sequence seq) {
      DEREncodable var2;
      if ((var2 = seq.getObjectAt(0)).getDERObject() instanceof DERUTF8String) {
         this.contentDescription = DERUTF8String.getInstance(var2);
         this.contentType = DERObjectIdentifier.getInstance(seq.getObjectAt(1));
      } else {
         this.contentType = DERObjectIdentifier.getInstance(seq.getObjectAt(0));
      }

   }

   public ContentHints(DERObjectIdentifier contentType) {
      this.contentType = contentType;
      this.contentDescription = null;
   }

   public ContentHints(DERObjectIdentifier contentType, DERUTF8String contentDescription) {
      this.contentType = contentType;
      this.contentDescription = contentDescription;
   }

   public DERObjectIdentifier getContentType() {
      return this.contentType;
   }

   public DERUTF8String getContentDescription() {
      return this.contentDescription;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERUTF8String var2;
      if ((var2 = this.contentDescription) != null) {
         var1.add(var2);
      }

      var1.add(this.contentType);
      return new DERSequence(var1);
   }
}
